@@ -5,6 +5,7 @@ from PIL import Image
 from selenium.webdriver.common.keys import Keys
 
 from .captcha import Captcha
+from ..exceptions import NoCaptchaException
 
 
 class ImageCaptcha(Captcha):
@@ -38,7 +39,12 @@ class ImageCaptcha(Captcha):
         """
         if self.params["browser"]:
             self._get_captcha_img()
-        self._encode_image()
+
+        try:
+            self._encode_image()
+        except Exception:
+            raise NoCaptchaException("Cannot find ImageCaptcha!")
+
         self.service_provider.post_in(self.body)
         self.token = self.service_provider.get_res()
 
